@@ -5,16 +5,18 @@ import (
 	"os"
 	"time"
 
+	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
+
 	"github.com/spf13/cobra"
 )
 
 // configCmd represents the config command
 var configCmd = &cobra.Command{
-	Use:   "config [export|migrate|edit]",
+	Use:   "config edit",
 	Short: "Interact with the config",
 	Long: `Interact with the config.
 
-You can export, migrate or edit the config.`,
+You can export, migrate or edit the config (via the editor specified in the environment variable "EDITOR").`,
 	ValidArgs: []string{
 		"export",
 		"migrate",
@@ -29,7 +31,13 @@ You can export, migrate or edit the config.`,
 		}
 		switch args[0] {
 		case "edit":
-			editFileWithEditor(os.Getenv("POSH_THEME"))
+			env := &runtime.Terminal{
+				CmdFlags: &runtime.Flags{
+					Config: configFlag,
+				},
+			}
+			env.ResolveConfigPath()
+			os.Exit(editFileWithEditor(env.CmdFlags.Config))
 		case "get":
 			// only here for backwards compatibility
 			fmt.Print(time.Now().UnixNano() / 1000000)
