@@ -649,11 +649,13 @@ func TestGitCleanSSHURL(t *testing.T) {
 		{Case: "gitea no port, no user", Expected: "https://src.example.com/user/repo", Upstream: "_gitea@src.example.com:user/repo.git"},
 		{Case: "git@ with user", Expected: "https://github.com/JanDeDobbeleer/oh-my-posh", Upstream: "git@github.com:JanDeDobbeleer/oh-my-posh"},
 		{Case: "unsupported", Upstream: "\\test\\repo.git"},
+		{Case: "Azure DevOps, https", Expected: "https://dev.azure.com/posh/oh-my-posh/_git/website", Upstream: "https://posh@dev.azure.com/posh/oh-my-posh/_git/website"},
+		{Case: "Azure DevOps, ssh", Expected: "https://dev.azure.com/posh/oh-my-posh/_git/website", Upstream: "git@ssh.dev.azure.com:v3/posh/oh-my-posh/website"},
 	}
 	for _, tc := range cases {
 		g := &Git{}
-		upstreamIcon := g.cleanUpstreamURL(tc.Upstream)
-		assert.Equal(t, tc.Expected, upstreamIcon, tc.Case)
+		upstreamURL := g.cleanUpstreamURL(tc.Upstream)
+		assert.Equal(t, tc.Expected, upstreamURL, tc.Case)
 	}
 }
 
@@ -988,6 +990,7 @@ func TestGitCommit(t *testing.T) {
 			at:1673176335
 			su:docs(error): you can't use cross segment properties
 			ha:1234567891011121314
+			rf:HEAD -> refs/heads/main, tag: refs/tags/tag-1, tag: refs/tags/0.3.4, refs/remotes/origin/main, refs/remotes/origin/dev, refs/heads/dev, refs/remotes/origin/HEAD
 			`,
 			Expected: &Commit{
 				Author: &User{
@@ -1000,7 +1003,12 @@ func TestGitCommit(t *testing.T) {
 				},
 				Subject:   "docs(error): you can't use cross segment properties",
 				Timestamp: time.Unix(1673176335, 0),
-				Sha:       "1234567891011121314",
+				Refs: &Refs{
+					Tags:    []string{"tag-1", "0.3.4"},
+					Heads:   []string{"main", "dev"},
+					Remotes: []string{"origin/main", "origin/dev"},
+				},
+				Sha: "1234567891011121314",
 			},
 		},
 		{
@@ -1008,6 +1016,7 @@ func TestGitCommit(t *testing.T) {
 			Expected: &Commit{
 				Author:    &User{},
 				Committer: &User{},
+				Refs:      &Refs{},
 			},
 		},
 		{
@@ -1028,6 +1037,44 @@ func TestGitCommit(t *testing.T) {
 				},
 				Subject:   "docs(error): you can't use cross segment properties",
 				Timestamp: time.Unix(1673176335, 0),
+				Refs:      &Refs{},
+			},
+		},
+		{
+			Case: "No refs",
+			Output: `
+			rf:HEAD
+			`,
+			Expected: &Commit{
+				Author:    &User{},
+				Committer: &User{},
+				Refs:      &Refs{},
+			},
+		},
+		{
+			Case: "Just tag ref",
+			Output: `
+			rf:HEAD, tag: refs/tags/tag-1
+			`,
+			Expected: &Commit{
+				Author:    &User{},
+				Committer: &User{},
+				Refs: &Refs{
+					Tags: []string{"tag-1"},
+				},
+			},
+		},
+		{
+			Case: "Feature branch including slash",
+			Output: `
+			rf:HEAD, tag: refs/tags/feat/feat-1
+			`,
+			Expected: &Commit{
+				Author:    &User{},
+				Committer: &User{},
+				Refs: &Refs{
+					Tags: []string{"feat/feat-1"},
+				},
 			},
 		},
 		{
@@ -1038,13 +1085,14 @@ func TestGitCommit(t *testing.T) {
 			Expected: &Commit{
 				Author:    &User{},
 				Committer: &User{},
+				Refs:      &Refs{},
 			},
 		},
 	}
 
 	for _, tc := range cases {
 		env := new(mock.Environment)
-		env.MockGitCommand("", tc.Output, "log", "-1", "--pretty=format:an:%an%nae:%ae%ncn:%cn%nce:%ce%nat:%at%nsu:%s%nha:%H")
+		env.MockGitCommand("", tc.Output, "log", "-1", "--pretty=format:an:%an%nae:%ae%ncn:%cn%nce:%ce%nat:%at%nsu:%s%nha:%H%nrf:%D", "--decorate=full")
 		g := &Git{
 			scm: scm{
 				env:     env,
